/**********************************************************************
 *	ԊORR[he[u
 **********************************************************************
 */
#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>

#include "config.h"
#include "task.h"
#include "timer.h"
#include "usart.h"

/*
L[}gNX

                       PD= PullDownR

			   PD2     PD3     PD4     PD5     PD6
                 |       |       |       |       |  
                 |       |       |       |       |  
	PB0	---------+-------+-------+-------+-------+--
                 |(1)    |(2)    |(3)    |(4)    |(5)  
                 |       |       |       |       |  
	PB1	---------+-------+-------+-------+-------+--
                 |(6)    |(7)    |(8)    |(9)    |(10) 
                 |       |       |       |       |  
	PB2	---------+-------+-------+-------+-------+--
                 |(11)   |(12)   |(AD)   |(POW)  |  
                 |       |       |       |       |  
	PB3	---------+-------+-------+-------+-------+--
                 |(+)    |(-)    |       |(CH)   |  
                 |       |       |       |       |  
	PB4	---------+-------+-------+-------+-------+--
                 |(Mute) |       |       |(Video)|  
PB=PullUpZX



RoM
Diga
POW 02 20 80 00 3d bd
1   02 20 80 09 40 c9
2   02 20 80 09 41 c8
3   02 20 80 09 42 cb
4   02 20 80 09 43 ca
5   02 20 80 09 44 cd
6   02 20 80 09 45 cc
7   02 20 80 09 46 cf
8   02 20 80 09 47 ce
9   02 20 80 09 48 c1
10  02 20 80 09 49 c0
11  02 20 80 09 4a c3
12  02 20 80 09 4b c2
+   02 20 80 00 20 a0
-   02 20 80 00 21 a1

Aquos
POW	aa 5a 8f 12 16 d1	
1   aa 5a 8f 12 4e 32   
2   aa 5a 8f 12 4f 22   
3   aa 5a 8f 12 50 c2	
4   aa 5a 8f 12 51 d2	
5   aa 5a 8f 12 52 e2	
6   aa 5a 8f 12 53 f2	
7   aa 5a 8f 12 54 82	
8   aa 5a 8f 12 55 92	
9   aa 5a 8f 12 56 a2	
10  aa 5a 8f 12 57 b2	
11  aa 5a 8f 12 58 42	
12  aa 5a 8f 12 59 52	
+   aa 5a 8f 12 14 f1	
-   aa 5a 8f 12 15 e1	
*/

#define	VUP	13
#define	VDN	14

PROGMEM static uchar key_to_code[]={
//	PD2	PD3	PD4	PD5	PD6	--	--	--
	1,	2,	3,	4,	5,	0,	0,	0,	// PB0
	6,	7,	8,	9, 10, 	0,	0,	0,	// PB1
	11,	12,	0,	0,	0,	0,	0,	0,	// PB2
	VUP,VDN,0,	0,	0,	0,	0,	0,	// PB3
	0,	0,	0,	0,	0,	0,	0,	0,	// PB4
};

PROGMEM static uchar remocon_table[]={
	0x02 ,0x20 ,0x80 ,	//   DIGA prefix
//-------------------------------------
	0x00 ,0x3d ,0xbd ,	//   POW 
    0x09 ,0x40 ,0xc9 ,  //    1   
    0x09 ,0x41 ,0xc8 ,  //    2   
    0x09 ,0x42 ,0xcb ,  //    3   
    0x09 ,0x43 ,0xca ,  //    4   
    0x09 ,0x44 ,0xcd ,  //    5   
    0x09 ,0x45 ,0xcc ,  //    6   
    0x09 ,0x46 ,0xcf ,  //    7   
    0x09 ,0x47 ,0xce ,  //    8   
    0x09 ,0x48 ,0xc1 ,  //    9   
    0x09 ,0x49 ,0xc0 ,  //    10  
    0x09 ,0x4a ,0xc3 ,  //    11  
    0x09 ,0x4b ,0xc2 ,  //    12  
    0x00 ,0x20 ,0xa0 ,  //    +   
    0x00 ,0x21 ,0xa1 ,  //    -   


//	====================================


	0xaa ,0x5a ,0x8f ,	//   AQUOS prefix
//-------------------------------------
	0x12 ,0x16 ,0xd1 ,	//   POW 
    0x12 ,0x4e ,0x32 ,  //    1   
    0x12 ,0x4f ,0x22 ,  //    2   
    0x12 ,0x50 ,0xc2 ,  //    3   
    0x12 ,0x51 ,0xd2 ,  //    4   
    0x12 ,0x52 ,0xe2 ,  //    5   
    0x12 ,0x53 ,0xf2 ,  //    6   
    0x12 ,0x54 ,0x82 ,  //    7   
    0x12 ,0x55 ,0x92 ,  //    8   
    0x12 ,0x56 ,0xa2 ,  //    9   
    0x12 ,0x57 ,0xb2 ,  //    10  
    0x12 ,0x58 ,0x42 ,  //    11  
    0x12 ,0x59 ,0x52 ,  //    12  
    0x12 ,0x14 ,0xf1 ,  //    +   
    0x12 ,0x15 ,0xe1 ,  //    -   
};

/**********************************************************************
 *	
 **********************************************************************
 */ 
static	uchar tbl(uchar idx)
{
	return __LPM( &remocon_table[idx] );
}
/**********************************************************************
 *	
 **********************************************************************
 */ 
static	uchar to_code(uchar key)
{
	return __LPM( &key_to_code[key] );
}
/**********************************************************************
 *	
 **********************************************************************
 */ 
void set_code(uchar *buf,uchar maker_id,uchar key)
{
	uchar code_id = to_code(key);
	uchar idx = maker_id * 16 * 3;
	buf[0] = tbl(idx++);
	buf[1] = tbl(idx++);
	buf[2] = tbl(idx++);

	idx += (code_id * 3);

	buf[3] = tbl(idx++);
	buf[4] = tbl(idx++);
	buf[5] = tbl(idx++);
}
/**********************************************************************
 *	
 **********************************************************************
 */ 
